@@ -21,6 +21,11 @@ Implementation Notes
 
 """
 
+try:
+    from typing import Optional
+except ImportError:
+    pass
+
 from adafruit_display_shapes.roundrect import RoundRect
 
 __version__ = "0.0.0-auto.0"
@@ -42,7 +47,16 @@ class Circle(RoundRect):
 
     """
 
-    def __init__(self, x0, y0, r, *, fill=None, outline=None, stroke=1):
+    def __init__(
+        self,
+        x0: int,
+        y0: int,
+        r: int,
+        *,
+        fill: Optional[int] = None,
+        outline: Optional[int] = None,
+        stroke: int = 1,
+    ) -> None:
         super().__init__(
             x0 - r,
             y0 - r,
@@ -56,19 +70,19 @@ class Circle(RoundRect):
         self.r = r
 
     @property
-    def x0(self):
+    def x0(self) -> int:
         """The x-position of the center of the circle."""
         return self.x + self.r
 
     @property
-    def y0(self):
+    def y0(self) -> int:
         """The y-position of the center of the circle."""
         return self.y + self.r
 
     @x0.setter
-    def x0(self, x0):
+    def x0(self, x0: int) -> None:
         self.x = x0 - self.r
 
     @y0.setter
-    def y0(self, y0):
+    def y0(self, y0: int) -> None:
         self.y = y0 - self.r
