@@ -21,6 +21,11 @@ Implementation Notes
 
 """
 
+try:
+    from typing import Optional, List, Tuple
+except ImportError:
+    pass
+
 import displayio
 
 __version__ = "0.0.0-auto.0"
@@ -36,7 +41,12 @@ class Polygon(displayio.TileGrid):
                     ``None`` for no outline.
     """
 
-    def __init__(self, points, *, outline=None):
+    def __init__(
+        self,
+        points: List[Tuple[int, int]],
+        *,
+        outline: Optional[int] = None,
+    ) -> None:
         xs = []
         ys = []
 
@@ -77,7 +87,14 @@ class Polygon(displayio.TileGrid):
         )
 
     # pylint: disable=invalid-name, too-many-locals, too-many-branches
-    def _line(self, x0, y0, x1, y1, color):
+    def _line(
+        self,
+        x0: int,
+        y0: int,
+        x1: int,
+        y1: int,
+        color: int,
+    ) -> None:
         if x0 == x1:
             if y0 > y1:
                 y0, y1 = y1, y0
@@ -121,13 +138,13 @@ class Polygon(displayio.TileGrid):
     # pylint: enable=invalid-name, too-many-locals, too-many-branches
 
     @property
-    def outline(self):
+    def outline(self) -> Optional[int]:
         """The outline of the polygon. Can be a hex value for a color or
         ``None`` for no outline."""
         return self._palette[1]
 
     @outline.setter
-    def outline(self, color):
+    def outline(self, color: Optional[int]) -> None:
         if color is None:
             self._palette[1] = 0
             self._palette.make_transparent(1)
